==> drupal-10.0.0-rc1.tar.gz: drupal-10.0.0-rc1/core/modules/media/js/type_form.js <==
/**
 * @file
 * Defines JavaScript behaviors for the media type form.
 */

(function ($, Drupal) {
  /**
   * Behaviors for setting summaries on media type form.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches summary behaviors on media type edit forms.
   */
  Drupal.behaviors.mediaTypeFormSummaries = {
    attach(context) {
      const $context = $(context);
      // Provide the vertical tab summaries.
      $context.find('#edit-workflow').drupalSetSummary((context) => {
        const vals = [];
        $(context)
          .find('input[name^="options"]:checked')
          .parent()
          .each(function () {
            vals.push(Drupal.checkPlain($(this).find('label')[0].textContent));
          });
        if (!$(context).find('#edit-options-status').is(':checked')) {
          vals.unshift(Drupal.t('Not published'));
        }
        return vals.join(', ');
      });
      $(context)
        .find('#edit-language')
        .drupalSetSummary((context) => {
          const vals = [];

          vals.push(
            $(context).find(
              '.js-form-item-language-configuration-langcode select option:selected',
            )[0].textContent,
          );

          $(context)
            .find('input:checked')
            .next('label')
            .each(function () {
              vals.push(Drupal.checkPlain(this.textContent));
            });

          return vals.join(', ');
        });
    },
  };
})(jQuery, Drupal);

==> drupal-11.0.0.tar.gz: drupal-11.0.0/core/modules/media/js/type_form.js <==
/**
 * @file
 * Defines JavaScript behaviors for the media type form.
 */

(function ($, Drupal) {
  /**
   * Behaviors for setting summaries on media type form.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches summary behaviors on media type edit forms.
   */
  Drupal.behaviors.mediaTypeFormSummaries = {
    attach(context) {
      const $context = $(context);
      // Provide the vertical tab summaries.
      $context.find('#edit-workflow').drupalSetSummary((context) => {
        const values = [];
        $(context)
          .find('input[name^="options"]:checked')
          .parent()
          .each(function () {
            values.push(
              Drupal.checkPlain($(this).find('label')[0].textContent),
            );
          });
        if ($(context).find('#edit-options-status:checked').length === 0) {
          values.unshift(Drupal.t('Not published'));
        }
        return values.join(', ');
      });
      $(context)
        .find('#edit-language')
        .drupalSetSummary((context) => {
          const values = [];

          values.push(
            $(context).find(
              '.js-form-item-language-configuration-langcode select option:selected',
            )[0].textContent,
          );

          $(context)
            .find('input:checked')
            .next('label')
            .each(function () {
              values.push(Drupal.checkPlain(this.textContent));
            });

          return values.join(', ');
        });
    },
  };
})(jQuery, Drupal);
